@@ -37,6 +37,8 @@ class asyauthSecret(enum.Enum):
 	KEYTABHEX = 'KEYTABHEX'
 	KEYTABB64 = 'KEYTABB64'
 	PFX = 'PFX'
+	PFXB64 = 'PFXB64'
+	PFXHEX = 'PFXHEX'
 	PFXSTR = 'PFXSTR'
 	PEM = 'PEM'
 	CERTSTORE = 'CERTSTORE'
